# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.users_api import UsersApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.users_api.UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_user(self):
        """Test case for delete_user

        Remove a user from an organisation  # noqa: E501
        """
        pass

    def test_get_all_user_orgs(self):
        """Test case for get_all_user_orgs

        Return all organisations a user has been assigned to  # noqa: E501
        """
        pass

    def test_get_all_user_roles(self):
        """Test case for get_all_user_roles

        Return all roles for a user  # noqa: E501
        """
        pass

    def test_get_user(self):
        """Test case for get_user

        Get a single user  # noqa: E501
        """
        pass

    def test_get_user_permissions(self):
        """Test case for get_user_permissions

        Return the user's host permissions  # noqa: E501
        """
        pass

    def test_get_users(self):
        """Test case for get_users

        Get all users  # noqa: E501
        """
        pass

    def test_get_users_list(self):
        """Test case for get_users_list

        Get a list of all user GUIDs  # noqa: E501
        """
        pass

    def test_post_user(self):
        """Test case for post_user

        Create a user  # noqa: E501
        """
        pass

    def test_put_user(self):
        """Test case for put_user

        Create or update a user  # noqa: E501
        """
        pass

    def test_put_user_role(self):
        """Test case for put_user_role

        Create or update a user role  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
